@@ -40,23 +40,40 @@ class Request:
     """
 
     def __init__(self, **kwargs):
-        self.id = kwargs.get(consts.ID)
-        self.type = kwargs.get(consts.TYPE)
-        self.note = kwargs.get(consts.NOTE)
-        self.asset = Asset(**kwargs.get(consts.ASSET))
-        self.reason = kwargs.get(consts.REASON)
-        self.status = kwargs.get(consts.STATUS)
-        self.created = kwargs.get(consts.CREATED)
-        self.updated = kwargs.get(consts.UPDATED)
-        self.answered = kwargs.get(consts.ANSWERED)
-        self.assignee = kwargs.get(consts.ASSIGNEE)
-        self.activation_key = kwargs.get(consts.ACTIVATION_KEY)
-        self.previous_approved_request = kwargs.get(consts.PREVIOUS_APPROVED_REQUEST)
-        self.effective_date = kwargs.get(consts.EFFECTIVE_DATE)
-        self.planned_date = kwargs.get(consts.PLANNED_DATE)
-        self.events = Events(**kwargs.get(consts.EVENTS))
-        self.marketplace = Marketplace(**kwargs.get(consts.MARKETPLACE))
-        self.contract = Named(**kwargs.get(consts.CONTRACT))
+        if consts.ID in kwargs:
+            self.id = kwargs.get(consts.ID)
+        if consts.TYPE in kwargs:
+            self.type = kwargs.get(consts.TYPE)
+        if consts.NOTE in kwargs:
+            self.note = kwargs.get(consts.NOTE)
+        if consts.ASSET in kwargs:
+            self.asset = Asset(**kwargs.get(consts.ASSET))
+        if consts.REASON in kwargs:
+            self.reason = kwargs.get(consts.REASON)
+        if consts.STATUS in kwargs:
+            self.status = kwargs.get(consts.STATUS)
+        if consts.CREATED in kwargs:
+            self.created = kwargs.get(consts.CREATED)
+        if consts.UPDATED in kwargs:
+            self.updated = kwargs.get(consts.UPDATED)
+        if consts.ANSWERED in kwargs:
+            self.answered = kwargs.get(consts.ANSWERED)
+        if consts.ASSIGNEE in kwargs:
+            self.assignee = kwargs.get(consts.ASSIGNEE)
+        if consts.ACTIVATION_KEY in kwargs:
+            self.activation_key = kwargs.get(consts.ACTIVATION_KEY)
+        if consts.PREVIOUS_APPROVED_REQUEST in kwargs:
+            self.previous_approved_request = kwargs.get(consts.PREVIOUS_APPROVED_REQUEST)
+        if consts.EFFECTIVE_DATE in kwargs:
+            self.effective_date = kwargs.get(consts.EFFECTIVE_DATE)
+        if consts.PLANNED_DATE in kwargs:
+            self.planned_date = kwargs.get(consts.PLANNED_DATE)
+        if consts.EVENTS in kwargs:
+            self.events = Events(**kwargs.get(consts.EVENTS))
+        if consts.MARKETPLACE in kwargs:
+            self.marketplace = Marketplace(**kwargs.get(consts.MARKETPLACE))
+        if consts.CONTRACT in kwargs:
+            self.contract = Named(**kwargs.get(consts.CONTRACT))
 
     def get_marketplace_id(self):
         return self.marketplace.id
@@ -110,15 +127,22 @@ class Param:
     """
 
     def __init__(self, **kwargs):
-        self.id = kwargs.get(consts.ID)
+        if consts.ID in kwargs:
+            self.id = kwargs.get(consts.ID)
         if consts.NAME in kwargs:
             self.name = kwargs.get(consts.NAME)
-        self.type = kwargs.get(consts.TYPE)
-        self.phase = kwargs.get(consts.PHASE)
-        self.description = kwargs.get(consts.DESCRIPTION)
-        self.value = kwargs.get(consts.VALUE)
-        self.title = kwargs.get(consts.TITLE)
-        self.constraints = Constraints(**kwargs.get(consts.CONSTRAINTS))
+        if consts.TYPE in kwargs:
+            self.type = kwargs.get(consts.TYPE)
+        if consts.PHASE in kwargs:
+            self.phase = kwargs.get(consts.PHASE)
+        if consts.DESCRIPTION in kwargs:
+            self.description = kwargs.get(consts.DESCRIPTION)
+        if consts.VALUE in kwargs:
+            self.value = kwargs.get(consts.VALUE)
+        if consts.TITLE in kwargs:
+            self.title = kwargs.get(consts.TITLE)
+        if consts.CONSTRAINTS in kwargs:
+            self.constraints = Constraints(**kwargs.get(consts.CONSTRAINTS))
         if consts.VALUE_ERROR in kwargs:
             self.value_error = kwargs.get(consts.VALUE_ERROR)
 
@@ -129,18 +153,28 @@ class ConfigurationParam:
     """
 
     def __init__(self, **kwargs):
-        self.value = kwargs.get(consts.VALUE)
-        self.events = Events(**kwargs.get(consts.EVENTS))
-        self.id = kwargs.get(consts.ID)
-        self.title = kwargs.get(consts.TITLE)
-        self.description = kwargs.get(consts.DESCRIPTION)
-        self.type = kwargs.get(consts.TYPE)
-        self.scope = kwargs.get(consts.SCOPE)
-        self.phase = kwargs.get(consts.PHASE)
-        self.hint = kwargs.get(consts.HINT)
+        if consts.VALUE in kwargs:
+            self.value = kwargs.get(consts.VALUE)
+        if consts.EVENTS in kwargs:
+            self.events = Events(**kwargs.get(consts.EVENTS))
+        if consts.ID in kwargs:
+            self.id = kwargs.get(consts.ID)
+        if consts.TITLE in kwargs:
+            self.title = kwargs.get(consts.TITLE)
+        if consts.DESCRIPTION in kwargs:
+            self.description = kwargs.get(consts.DESCRIPTION)
+        if consts.TYPE in kwargs:
+            self.type = kwargs.get(consts.TYPE)
+        if consts.SCOPE in kwargs:
+            self.scope = kwargs.get(consts.SCOPE)
+        if consts.PHASE in kwargs:
+            self.phase = kwargs.get(consts.PHASE)
+        if consts.HINT in kwargs:
+            self.hint = kwargs.get(consts.HINT)
         if consts.PLACEHOLDER in kwargs:
             self.placeholder = kwargs.get(consts.PLACEHOLDER)
-        self.constraints = Constraints(**kwargs.get(consts.CONSTRAINTS))
+        if consts.CONSTRAINTS in kwargs:
+            self.constraints = Constraints(**kwargs.get(consts.CONSTRAINTS))
 
 
 class ParamsManager:
@@ -211,7 +245,8 @@ class Configuration(ParamsManager):
     """
 
     def __init__(self, **kwargs):
-        super().__init__([ConfigurationParam(**p) for p in kwargs.get(consts.PARAMS)])
+        if consts.PARAMS in kwargs:
+            super().__init__([ConfigurationParam(**p) for p in kwargs.get(consts.PARAMS)])
 
 
 class Item(ParamsManager):
@@ -223,15 +258,24 @@ class Item(ParamsManager):
         if consts.PARAMS in kwargs:
             super().__init__([Param(**p) for p in kwargs.get(consts.PARAMS)])
 
-        self.id = kwargs.get(consts.ID)
-        self.global_id = kwargs.get(consts.GLOBAL_ID)
-        self.mpn = kwargs.get(consts.MPN)
-        self.old_quantity = int(kwargs.get(consts.OLD_QUANTITY))
-        self.quantity = int(kwargs.get(consts.QUANTITY))
-        self.type = kwargs.get(consts.TYPE)
-        self.display_name = kwargs.get(consts.DISPLAY_NAME)
-        self.period = kwargs.get(consts.PERIOD)
-        self.item_type = kwargs.get(consts.ITEM_TYPE)
+        if consts.ID in kwargs:
+            self.id = kwargs.get(consts.ID)
+        if consts.GLOBAL_ID in kwargs:
+            self.GLOBAL_ID = kwargs.get(consts.GLOBAL_ID)
+        if consts.MPN in kwargs:
+            self.mpn = kwargs.get(consts.MPN)
+        if consts.OLD_QUANTITY in kwargs:
+            self.old_quantity = int(kwargs.get(consts.OLD_QUANTITY))
+        if consts.QUANTITY in kwargs:
+            self.quantity = int(kwargs.get(consts.QUANTITY))
+        if consts.TYPE in kwargs:
+            self.type = kwargs.get(consts.TYPE)
+        if consts.DISPLAY_NAME in kwargs:
+            self.display_name = kwargs.get(consts.DISPLAY_NAME)
+        if consts.PERIOD in kwargs:
+            self.period = kwargs.get(consts.PERIOD)
+        if consts.ITEM_TYPE in kwargs:
+            self.item_type = kwargs.get(consts.ITEM_TYPE)
 
 
 class Asset(ParamsManager):
@@ -240,20 +284,33 @@ class Asset(ParamsManager):
     """
 
     def __init__(self, **kwargs):
-        super().__init__([Param(**p) for p in kwargs.get(consts.PARAMS)])
+        if consts.PARAMS in kwargs:
+            super().__init__([Param(**p) for p in kwargs.get(consts.PARAMS)])
 
-        self.id = kwargs.get(consts.ID)
-        self.status = kwargs.get(consts.STATUS)
-        self.external_id = kwargs.get(consts.EXTERNAL_ID)
-        self.external_uid = kwargs.get(consts.EXTERNAL_UID)
-        self.product = Product(**kwargs.get(consts.PRODUCT))
-        self.connection = Connection(**kwargs.get(consts.CONNECTION))
-        self.events = Events(**kwargs.get(consts.EVENTS))
-        self.items = [Item(**item) for item in kwargs.get(consts.ITEMS)]
-        self.tiers = Tiers(**kwargs.get(consts.TIERS))
-        self.configuration = Configuration(**kwargs.get(consts.CONFIGURATION))
-        self.marketplace = Marketplace(**kwargs.get(consts.MARKETPLACE))
-        self.contract = Named(**kwargs.get(consts.CONTRACT))
+        if consts.ID in kwargs:
+            self.id = kwargs.get(consts.ID)
+        if consts.STATUS in kwargs:
+            self.status = kwargs.get(consts.STATUS)
+        if consts.EXTERNAL_ID in kwargs:
+            self.external_id = kwargs.get(consts.EXTERNAL_ID)
+        if consts.EXTERNAL_UID in kwargs:
+            self.external_uid = kwargs.get(consts.EXTERNAL_UID)
+        if consts.PRODUCT in kwargs:
+            self.product = Product(**kwargs.get(consts.PRODUCT))
+        if consts.CONNECTION in kwargs:
+            self.connection = Connection(**kwargs.get(consts.CONNECTION))
+        if consts.EVENTS in kwargs:
+            self.events = Events(**kwargs.get(consts.EVENTS))
+        if consts.ITEMS in kwargs:
+            self.items = [Item(**item) for item in kwargs.get(consts.ITEMS)]
+        if consts.TIERS in kwargs:
+            self.tiers = Tiers(**kwargs.get(consts.TIERS))
+        if consts.CONFIGURATION in kwargs:
+            self.configuration = Configuration(**kwargs.get(consts.CONFIGURATION))
+        if consts.MARKETPLACE in kwargs:
+            self.marketplace = Marketplace(**kwargs.get(consts.MARKETPLACE))
+        if consts.CONTRACT in kwargs:
+            self.contract = Named(**kwargs.get(consts.CONTRACT))
 
 
 class Tiers:
@@ -262,9 +319,12 @@ class Tiers:
     """
 
     def __init__(self, **kwargs):
-        self.customer = Tier(**kwargs.get(consts.CUSTOMER))
-        self.tier1 = Tier(**kwargs.get(consts.TIER1))
-        self.tier2 = Tier(**kwargs.get(consts.TIER2))
+        if consts.CUSTOMER in kwargs:
+            self.customer = Tier(**kwargs.get(consts.CUSTOMER))
+        if consts.TIER1 in kwargs:
+            self.tier1 = Tier(**kwargs.get(consts.TIER1))
+        if consts.TIER2 in kwargs:
+            self.tier2 = Tier(**kwargs.get(consts.TIER2))
 
 
 class Tier:
@@ -307,13 +367,20 @@ class ContactInfo:
     """
 
     def __init__(self, **kwargs):
-        self.address_line1 = kwargs.get(consts.ADDRESS_LINE1)
-        self.address_line2 = kwargs.get(consts.ADDRESS_LINE2)
-        self.city = kwargs.get(consts.CITY)
-        self.state = kwargs.get(consts.STATE)
-        self.postal_code = kwargs.get(consts.POSTAL_CODE)
-        self.country = kwargs.get(consts.COUNTRY)
-        self.contact = Contact(**kwargs.get(consts.CONTACT))
+        if consts.ADDRESS_LINE1 in kwargs:
+            self.address_line1 = kwargs.get(consts.ADDRESS_LINE1)
+        if consts.ADDRESS_LINE2 in kwargs:
+            self.address_line2 = kwargs.get(consts.ADDRESS_LINE2)
+        if consts.CITY in kwargs:
+            self.city = kwargs.get(consts.CITY)
+        if consts.STATE in kwargs:
+            self.state = kwargs.get(consts.STATE)
+        if consts.POSTAL_CODE in kwargs:
+            self.postal_code = kwargs.get(consts.POSTAL_CODE)
+        if consts.COUNTRY in kwargs:
+            self.country = kwargs.get(consts.COUNTRY)
+        if consts.CONTACT in kwargs:
+            self.contact = Contact(**kwargs.get(consts.CONTACT))
 
 
 class Contact:
@@ -322,10 +389,14 @@ class Contact:
     """
 
     def __init__(self, **kwargs):
-        self.first_name = kwargs.get(consts.FIRST_NAME)
-        self.last_name = kwargs.get(consts.LAST_NAME)
-        self.email = kwargs.get(consts.EMAIL)
-        self.phone_number = PhoneNumber(**kwargs.get(consts.PHONE_NUMBER))
+        if consts.FIRST_NAME in kwargs:
+            self.first_name = kwargs.get(consts.FIRST_NAME)
+        if consts.LAST_NAME in kwargs:
+            self.last_name = kwargs.get(consts.LAST_NAME)
+        if consts.EMAIL in kwargs:
+            self.email = kwargs.get(consts.EMAIL)
+        if consts.PHONE_NUMBER in kwargs:
+            self.phone_number = PhoneNumber(**kwargs.get(consts.PHONE_NUMBER))
 
 
 class PhoneNumber:
@@ -334,10 +405,14 @@ class PhoneNumber:
     """
 
     def __init__(self, **kwargs):
-        self.country_code = kwargs.get(consts.COUNTRY_CODE)
-        self.area_code = kwargs.get(consts.AREA_CODE)
-        self.phone_number = kwargs.get(consts.PHONE_NUMBER)
-        self.extension = kwargs.get(consts.EXTENSION)
+        if consts.COUNTRY_CODE in kwargs:
+            self.country_code = kwargs.get(consts.COUNTRY_CODE)
+        if consts.AREA_CODE in kwargs:
+            self.area_code = kwargs.get(consts.AREA_CODE)
+        if consts.PHONE_NUMBER in kwargs:
+            self.phone_number = kwargs.get(consts.PHONE_NUMBER)
+        if consts.EXTENSION in kwargs:
+            self.extension = kwargs.get(consts.EXTENSION)
 
 
 class Named:
@@ -346,8 +421,10 @@ class Named:
     """
 
     def __init__(self, **kwargs):
-        self.id = kwargs.get(consts.ID)
-        self.name = kwargs.get(consts.NAME)
+        if consts.ID in kwargs:
+            self.id = kwargs.get(consts.ID)
+        if consts.NAME in kwargs:
+            self.name = kwargs.get(consts.NAME)
 
 
 class Parent(Named):
@@ -357,7 +434,8 @@ class Parent(Named):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        self.external_id = kwargs.get(consts.EXTERNAL_ID)
+        if consts.EXTERNAL_ID in kwargs:
+            self.external_id = kwargs.get(consts.EXTERNAL_ID)
 
 
 class Events:
@@ -366,8 +444,10 @@ class Events:
     """
 
     def __init__(self, **kwargs):
-        self.created = Dated(**kwargs.get(consts.CREATED))
-        self.updated = Dated(**kwargs.get(consts.UPDATED))
+        if consts.CREATED in kwargs:
+            self.created = Dated(**kwargs.get(consts.CREATED))
+        if consts.UPDATED in kwargs:
+            self.updated = Dated(**kwargs.get(consts.UPDATED))
 
 
 class Dated:
@@ -376,7 +456,8 @@ class Dated:
     """
 
     def __init__(self, **kwargs):
-        self.at = kwargs.get(consts.AT)
+        if consts.AT in kwargs:
+            self.at = kwargs.get(consts.AT)
         if consts.BY in kwargs:
             self.by = Named(**kwargs.get(consts.BY))
 
@@ -388,7 +469,8 @@ class Marketplace(Named):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        self.icon = kwargs.get(consts.ICON)
+        if consts.ICON in kwargs:
+            self.icon = kwargs.get(consts.ICON)
 
 
 class Product(Named):
@@ -398,8 +480,10 @@ class Product(Named):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        self.icon = kwargs.get(consts.ICON)
-        self.status = kwargs.get(consts.STATUS)
+        if consts.ICON in kwargs:
+            self.icon = kwargs.get(consts.ICON)
+        if consts.STATUS in kwargs:
+            self.status = kwargs.get(consts.STATUS)
 
 
 class Constraints:
@@ -408,7 +492,8 @@ class Constraints:
     """
 
     def __init__(self, **kwargs):
-        self.required = kwargs.get(consts.REQUIRED)
+        if consts.REQUIRED in kwargs:
+            self.required = kwargs.get(consts.REQUIRED)
         if consts.META in kwargs:
             self.meta = kwargs.get(consts.META)
         if consts.MAX_LENGTH in kwargs:
@@ -435,8 +520,13 @@ class Connection:
     """
 
     def __init__(self, **kwargs):
-        self.id = kwargs.get(consts.ID)
-        self.type = kwargs.get(consts.TYPE)
-        self.provider = Named(**kwargs.get(consts.PROVIDER))
-        self.vendor = Named(**kwargs.get(consts.VENDOR))
-        self.hub = Named(**kwargs.get(consts.HUB))
+        if consts.ID in kwargs:
+            self.id = kwargs.get(consts.ID)
+        if consts.TYPE in kwargs:
+            self.type = kwargs.get(consts.TYPE)
+        if consts.PROVIDER in kwargs:
+            self.provider = Named(**kwargs.get(consts.PROVIDER))
+        if consts.VENDOR in kwargs:
+            self.vendor = Named(**kwargs.get(consts.VENDOR))
+        if consts.HUB in kwargs:
+            self.hub = Named(**kwargs.get(consts.HUB))
